dns_exporter Documentation
==========================

Welcome to the documentation for ``dns_exporter``.

The source code and issue tracker can be found on `Github <https://github.com/tykling/dns_exporter/>`_. This documentation was built with Sphinx from the `docs sources <https://github.com/tykling/dns_exporter/tree/develop/src/docs/source>`_.


Contents
========
.. toctree::
   :maxdepth: 2

   introduction
   quickstart
   configuration
   examples
   reference/index
   changelog


.. toctree::
   :hidden:
   :caption: Project Links

   Source Code <https://github.com/tykling/dns_exporter/>
   Issue Tracker <https://github.com/tykling/dns_exporter/issues/>
   PyPi <https://pypi.org/project/dns-exporter/>
